#
# spec file for package cmark
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libcmark0_27_1
Name:           cmark
Version:        0.27.1
Release:        3.1
Summary:        CommonMark parsing and rendering library and program in C
License:        BSD-2-Clause and MIT and CC-BY-SA-4.0
Group:          Productivity/Text/Utilities
Url:            https://github.com/jgm/cmark
Source:         https://github.com/jgm/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 3.0.2
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
`cmark` is the C reference implementation of CommonMark,
a rationalized version of Markdown syntax with a spec.

It provides a shared library (`libcmark`) with functions for parsing
CommonMark documents to an abstract syntax tree (AST), manipulating
the AST, and rendering the document to HTML, groff man, LaTeX,
CommonMark, or an XML representation of the AST.  It also provides a
command-line program (`cmark`) for parsing and rendering CommonMark
documents.

%package -n %{libname}
Summary:        CmmonMark parsing and rendering library
Group:          System/Libraries

%description -n %{libname}
It provides a shared library (`libcmark`) with functions for parsing
CommonMark documents to an abstract syntax tree (AST), manipulating
the AST, and rendering the document to HTML, groff man, LaTeX,
CommonMark, or an XML representation of the AST.  It also provides a
command-line program (`cmark`) for parsing and rendering CommonMark
documents.

%package devel
Summary:        Development files for cmark library
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}-%{release}

%description devel
This package provides the development files for cmark.

%prep
%setup -q

%build
%cmake -DCMARK_TESTS=OFF
%make_jobs

%install
%cmake_install
rm %{buildroot}%{_libdir}/libcmark.a

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING
%{_bindir}/cmark
%{_mandir}/man1/cmark.1%{?ext_man}

%files -n %{libname}
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libcmark.so.%{version}

%files devel
%defattr(-,root,root)
%{_includedir}/cmark.h
%{_includedir}/cmark_export.h
%{_includedir}/cmark_version.h
%{_libdir}/libcmark.so
%{_libdir}/pkgconfig/libcmark.pc
%{_mandir}/man3/cmark.3%{?ext_man}
%{_libdir}/cmake/cmark-*.cmake
%{_libdir}/cmake/cmark.cmake

%doc README.md

%changelog
* Sun Nov 20 2016 mimi.vx@gmail.com
- update to 0.27.1
  * Set policy for CMP0063 to avoid a warning
  * Use VERSION_GREATER to clean up cmake version test
* Fri Nov 18 2016 mimi.vx@gmail.com
- update to 0.27.0
  * Fix CMAKE_C_VISIBILITY_PRESET for cmake versions greater than 1.8
  * Fix for non-matching entities
  * Modified print_delimiters (commented out) so it compiles again.
  * make format: don't change order of includes.
  * Changed logic for null/eol checks
    only check once for "not at end of line"
    check for null before we check for newline characters (the previous
  patch would fail for NULL + CR)
  * Fix by not advancing past both \0 and \n
  * Add test for NUL-LF sequence
  * Fix memory leak in list parsing
  * Use cmark_mem to free where used to alloc
  * Allow a shortcut link before a
  * Allow tabs after setext header line
  * Don't let URI schemes start with spaces.
  * Fixed h2..h6 HTML blocks
  * Autolink scheme can contain digits
  * Fix nullary function declarations in cmark.h
* Sun Oct 16 2016 mpluskal@suse.com
- Use current cmake macros
* Wed Aug 31 2016 mpluskal@suse.com
- Fix building with different release types set via cmake
* Sat Jul 16 2016 mimi.vx@gmail.com
- update to 0.26.1
  * Removed unnecessary typedef that caused build failure on some platforms.
  * Use $(MAKE) in Makefile instead of hardcoded make
* Sat Jul 16 2016 mimi.vx@gmail.com
- update to 0.26.0
  * Implement spec changes for list items:
  + Empty list items cannot interrupt paragraphs.
  + Ordered lists cannot interrupt paragraphs unless they start with 1.
  + Removed "two blank lines break out of a list" feature.
  * Fix sourcepos for blockquotes.
  * Fix sourcepos for atx headers).
  * Fix ATX headers and thematic breaks to allow tabs as well as spaces.
  * Fix chunk_set_cstr with suffix of current string
  * Export targets on installation
  * Fix cmake warning about CMP0048
  * commonmark renderer: Ensure we don't have a blank line before a code block when
  it's the first thing in a list item.
  * Change parsing of strong/emph in response to spec changes. process_emphasis now
  gets better results in corner cases. The change is this: when considering
  matches between an interior delimiter run (one that can open and can close)
  and another delimiter run, we require that the sum of the lengths of the two
  delimiter runs mod 3 is not 0.
  * Ported Robin Stocker's changes to link parsing in jgm/CommonMark#101. This uses
  a separate stack for brackets, instead of putting them on the delimiter stack.
  This avoids the need for looking through the delimiter stack for
  the next bracket.
  * cmark_reference_lookup: Return NULL if reference is null string.
  * Fix character type detection in commonmark.c
  + Implement cmark_isalpha.
  + Check for ASCII character before implicit cast to char.
  + Use internal ctype functions in commonmark.c.
  * Better documentation of memory-freeing responsibilities. in cmark.h and
  its man page
  * Use library functions to insert nodes in emphasis/link processing. Previously we
  did this manually, which introduces many places where errors can creep in.
  * Correctly handle list marker followed only by spaces. Previously when a list
  marker was followed only by spaces, cmark expected the following content to be
  indented by the same number of spaces. But in this case we should treat the
  line just like a blank line and set list padding accordingly.
  * Fixed a number of issues relating to line wrapping.
  + Extend CMARK_OPT_NOBREAKS to all renderers and add --nobreaks.
  + Do not autowrap, regardless of width parameter, if CMARK_OPT_NOBREAKS is set.
  + Fixed CMARK_OPT_HARDBREAKS for LaTeX and man renderers.
  + Ensure that no auto-wrapping occurs if CMARK_OPT_NOBREAKS is enabled, or if
  output is CommonMark and CMARK_OPT_HARDBREAKS is enabled.
  * Set stdin to binary mode on Windows
  * Add library option to render softbreaks as spaces. Note that the NOBREAKS option
  is HTML-only
  * renderer: no_linebreaks instead of no_wrap. We generally want this option to
  prohibit any breaking in things like headers (not just wraps, but softbreaks).
  * Coerce realurllen to int. This is an alternate solution for pull request, which
  introduced a new warning on the comparison.
  * Remove unused variable link_text.
  * Improved safety checks in buffer.
  * Add new interface allowing specification of custom memory allocator for nodes.
  Added cmark_node_new_with_mem, cmark_parser_new_with_mem, cmark_mem to API.
  * Reduce storage size for nodes by using bit flags instead of separate booleans.
  * cmake: Global handler for OOM situations.
  * Add tests for memory exhaustion.
  * Document in man page and public header that one should use the same memory
  allocator for every node in a tree.
  * Fix ctypes in Python FFI calls (Nick Wellnhofer). This didn't cause problems
  so far because all types are 32-bit on 32-bit systems and arguments are passed
  in registers on x86-64. The wrong types could cause crashes on other
  platforms, though.
  * Remove spurious failures in roundtrip tests. In the commonmark writer we separate
  lists, and lists and indented code, using a dummy HTML comment.
  So in evaluating the round-trip tests, we now strip out these comments.
  We also normalize HTML to avoid issues having to do with line breaks.
  * Added to_commonmark in test/cmark.py (for round-trip tests).
  * spec_test.py - parameterize do_test with converter.
  * spec_tests.py: exit code is now sum of failures and errors. This ensures that
  a failing exit code will be given when there are errors, not just with failures.
  * Fixed round trip tests. Previously they actually ran cmark instead of
  the round-trip version, since there was a bug in setting the ROUNDTRIP variable.
  * Added new roundtrip_tests.py. This replaces the old use of simple shell scripts.
  It is much faster, and more flexible. (We will be able to do custom
  normalization and skip certain tests.)
  * Fix leak in api_test.
  * Makefile: have leakcheck stop on first error instead of going through all
  the formats and options and probably getting the same output.
  * Add regression tests.
* Tue Mar 29 2016 mimi.vx@gmail.com
-  update to 0.25.2
* Sun Oct 18 2015 kgronlund@suse.com
- Initial package for version 0.22.0
